pub enum TelemetryDropBehavior {
Flush,
Shutdown,
}Variants
Flush
The telemetry pipeline will be flushed everytime a Telemetry is dropped.
This is particularly useful to use in conjunction with the fact that Telemetry
is Clone: lazy initialize a Telemetry into a static LazyCell/LazyLock, and keep
returning clones of that value.
You are guaranteed that the pipeline will get flushed everytime one of these clone goes out
of scope.
Shutdown
The telemetry pipeline will be flushed and shutdown the first time a Telemetry is dropped.
The pipeline is then inactive, and all logs, traces and metrics are dropped.